Change Log for v0.3.x — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Change Log »

# Change Log for v0.3.x

## v0.3.0 - released: 30 Mar 2014

- Moved to beta development status
- Updated oppia-schema.xsd
- https://github.com/DigitalCampus/django-oppia/issues/131 - update for for visualizations
- https://github.com/DigitalCampus/django-oppia/issues/130 - updated docs for new util files
- https://github.com/DigitalCampus/django-oppia/issues/10 - fix icon url in awards API

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Change Log »